@@ -49,9 +49,9 @@ class TokenizerTestCase(basetest.BaseTestCase):
         r'\(': [('IDENT', r'\(', 1, 1)],
         r'\1 \22 \333 \4444 \55555 \666666 \777777 7 \7777777':
             [(
-                ('IDENT', '\x01"\\u0333\\u4444\\U00055555\\666666 \\777777 7', 1, 1)
+                ('IDENT', '\x01"\u0333\u4444\U00055555\\666666 \\777777 7', 1, 1)
                 if sys.maxunicode > 0x10000 else
-                ('IDENT', '\x01"\\u0333\\u4444\\55555 \\666666 \\777777 7', 1, 1)
+                ('IDENT', '\x01"\u0333\u4444\\55555 \\666666 \\777777 7', 1, 1)
             ),
             ('S', ' ', 1, 43),
             ('IDENT', '\\7777777', 1, 44)
@@ -62,11 +62,11 @@ class TokenizerTestCase(basetest.BaseTestCase):
 
         '\\1 b': [('IDENT', '\x01b', 1, 1)],
         '\\44 b': [('IDENT', 'Db', 1, 1)],
-        '\\123 b': [('IDENT', '\\u0123b', 1, 1)],
-        '\\1234 b': [('IDENT', '\\u1234b', 1, 1)],
+        '\\123 b': [('IDENT', '\u0123b', 1, 1)],
+        '\\1234 b': [('IDENT', '\u1234b', 1, 1)],
         '\\12345 b':
             [(
-                ('IDENT', '\\U00012345b', 1, 1)
+                ('IDENT', '\U00012345b', 1, 1)
                 if sys.maxunicode > 0x10000 else
                 ('IDENT', '\\12345 b', 1, 1)
             )],
